@@ -220,12 +220,19 @@ BigDecimal BigDecimal::mul(const BigDecimal& d) const
 
 BigDecimal BigDecimal::div(const BigDecimal& d) const
 {
-    
     Chain v1 = _val;
     Chain v2 = d._val;
 
-    if ( v1 == Chain("00") )
-	return BigDecimal();
+    int i=0;
+    while ( i < v1.length() )
+    {
+        if ( v1[i] != '0' )
+           break;
+        i++;
+    }
+
+    if ( i == v1.length() - 1 )
+        return BigDecimal();
 	 
     int maxScale;
     int corScale;
